// Copyright 1997-1998 Omni Development, Inc.  All rights reserved.
//
// This software may only be used and reproduced according to the
// terms in the file OmniSourceLicense.html, which should be
// distributed with this project and can also be found at
// http://www.omnigroup.com/DeveloperResources/OmniSourceLicense.html.

#import "OWImagingPreferences.h"

#import <Foundation/Foundation.h>
#import <AppKit/AppKit.h>
#import <OmniBase/OmniBase.h>
#import <OmniFoundation/OmniFoundation.h>
#import <OmniAppKit/OmniAppKit.h>
#import <OIF/OIF.h>

RCS_ID("$Header: /Network/Developer/Source/CVS/OmniGroup/OmniImage/Preferences.bproj/OWImagingPreferences.m,v 1.11 1998/12/10 21:50:22 kc Exp $")

@interface OWImagingPreferences (Private)
- (void)updateAnimationMatrixAndField;
@end

@implementation OWImagingPreferences

- (void)updateUI;
{
    [minDrawIntervalField setFloatValue:[defaults floatForKey:@"OIImageProcessorDrawInterval"]];
    [minRowsIntervalField setIntValue:[defaults integerForKey:@"OIImageProcessorCheckTimeEveryNRows"]];
    [gammaCorrectionField setFloatValue:[defaults floatForKey:@"OIGammaCorrection"]];

    [self updateAnimationMatrixAndField];
}

- (void)setValueForSender:sender;
{
    if (sender == minDrawIntervalField) {
	if ([sender floatValue] > 0.0)
            [defaults setFloat:[sender floatValue] forKey:@"OIImageProcessorDrawInterval"];
	else
            [self resetFloatValueToDefaultNamed:@"OIImageProcessorDrawInterval" inTextField:sender];
    }
    else if (sender == minRowsIntervalField) {
	if ([sender intValue] > 0)
            [defaults setInteger:[sender intValue] forKey:@"OIImageProcessorCheckTimeEveryNRows"];
        else
            [self resetIntValueToDefaultNamed:@"OIImageProcessorCheckTimeEveryNRows" inTextField:sender];
    }
    else if (sender == gammaCorrectionField) {
        if ([sender floatValue] > 0 && [sender floatValue] < 10)
            [defaults setFloat:[sender floatValue] forKey:@"OIGammaCorrection"];
        else
            [self resetFloatValueToDefaultNamed:@"OIGammaCorrection" inTextField:sender];
    }
    else if (sender == animateCyclesField) {
        if ([sender intValue] >= 0)
            [defaults setInteger:[sender intValue] forKey:@"OIAnimationMaxLoops"];
        [self updateAnimationMatrixAndField];
    }
    else if (sender == animateBehaviorMatrix) {
        unsigned int animationMaxLoops;

        animationMaxLoops = [defaults integerForKey:@"OIAnimationMaxLoops"];

        switch ([sender selectedRow]) {
            case 0:
                [defaults setInteger:0 forKey:@"OIAnimationMaxLoops"];
                break;
            case 1:
                if (animationMaxLoops != 0 && animationMaxLoops != OIAnimationInfiniteLoopCount)
                    [defaults setInteger:animationMaxLoops forKey:@"OIAnimationMaxLoops"];
                else
                    [defaults setInteger:20 forKey:@"OIAnimationMaxLoops"];
                break;
            case 2:
                [defaults setInteger:OIAnimationInfiniteLoopCount forKey:@"OIAnimationMaxLoops"];
                break;
        }
        [self updateAnimationMatrixAndField];
    }
}

// NSNibAwaking informal protocol

- (void)awakeFromNib;
{
    [super awakeFromNib];
    
    // Ints
    [[minRowsIntervalField cell] setEntryType:NSPositiveIntType];
    [[animateCyclesField cell] setEntryType:NSPositiveIntType];

    // Floats
    [[minDrawIntervalField cell] setEntryType:NSPositiveFloatType];
    [[gammaCorrectionField cell] setEntryType:NSPositiveFloatType];
        
    [minDrawIntervalField setFloatingPointFormat:NO left:2 right:1];
    [gammaCorrectionField setFloatingPointFormat:NO left:2 right:1];
}

@end

@implementation OWImagingPreferences (Private)

- (void)updateAnimationMatrixAndField;
{
    unsigned int animationMaxLoops;
    
    // Animation
    animationMaxLoops = [defaults integerForKey:@"OIAnimationMaxLoops"];
    switch (animationMaxLoops) {
        case 0:
            [animateBehaviorMatrix selectCellAtRow:0 column:0];
            [animateCyclesField setStringValue:@""];
            break;
        default:
            [animateBehaviorMatrix selectCellAtRow:1 column:0];
            [animateCyclesField setIntValue:animationMaxLoops];
            break;
        case OIAnimationInfiniteLoopCount:
            [animateBehaviorMatrix selectCellAtRow:2 column:0];
            [animateCyclesField setStringValue:@""];
            break;
    }
}

@end
